@@ -51,16 +51,17 @@ getmM <- function(x,from=NA,to=NA,log=FALSE){
     else { getm <- FALSE }
     if (is.na(to)) { to <- max(x,na.rm=TRUE); getM <- TRUE }
     else { getM <- FALSE }
+    dx <- to-from
     if (getm) {
-        if (log) { from <- from/2 }
+        if (log) { from <- max(from/2,from-dx) }
         else {
-            if (2*from-to<0) {from <- 0}
-            else {from <- from-(to-from)/10}
+            if ((2*from-to)<0) {from <- 0}
+            else {from <- from-dx/10}
         }
     }
     if (getM) {
-        if (log) { to <- 2*to }
-        else { to <- to+(to-from)/10 }
+        if (log) { to <- min(2*to,to+dx) }
+        else { to <- to+dx/10 }
     }
     list(m=from,M=to)
 }
@@ -97,17 +98,17 @@ cor2cov4 <- function(sW,sX,sY,sZ,rWX,rWY,rWZ,rXY,rXZ,rYZ){
     covmat
 }
 
-get.cov.div <- function(A,err.A,B,err.B,AB,err.AB){
+get_cov_div <- function(A,err.A,B,err.B,AB,err.AB){
     0.5*A*B*((err.A/A)^2+(err.B/B)^2-(err.AB/AB)^2)
 }
-get.cor.div <- function(A,err.A,B,err.B,AB,err.AB){
-    get.cov.div(A,err.A,B,err.B,AB,err.AB)/(err.A*err.B)
+get_cor_div <- function(A,err.A,B,err.B,AB,err.AB){
+    get_cov_div(A,err.A,B,err.B,AB,err.AB)/(err.A*err.B)
 }
-get.cov.mult <- function(A,err.A,B,err.B,AB,err.AB){
+get_cov_mult <- function(A,err.A,B,err.B,AB,err.AB){
     0.5*A*B*((err.AB/AB)^2 - (err.A/A)^2 - (err.B/B)^2)
 }
-get.cor.mult <- function(A,err.A,B,err.B,AB,err.AB){
-    get.cov.mult(A,err.A,B,err.B,AB,err.AB)/(err.A*err.B)
+get_cor_mult <- function(A,err.A,B,err.B,AB,err.AB){
+    get_cov_mult(A,err.A,B,err.B,AB,err.AB)/(err.A*err.B)
 }
 
 # Implements Equations 6 & 7 of Ludwig (1998)
@@ -200,7 +201,7 @@ fixroundingerr <- function(v){
 }
 
 # simultaneously performs error propagation for multiple samples
-errorprop <- function(J11,J12,J21,J22,E11,E22,E12){
+errorprop <- function(J11,J12,J21,J22,E11,E22,E12=0){
     out <- matrix(0,length(J11),3)
     colnames(out) <- c('varX','varY','cov')
     out[,'varX'] <- fixroundingerr(J11*J11*E11 + J11*J12*E12 + J11*J12*E12 + J12*J12*E22)
@@ -208,7 +209,7 @@ errorprop <- function(J11,J12,J21,J22,E11,E22,E12){
     out[,'cov'] <- J11*J21*E11 + J12*J21*E12 + J11*J22*E12 + J12*J22*E22
     out
 }
-errorprop1x2 <- function(J1,J2,E11,E22,E12){
+errorprop1x2 <- function(J1,J2,E11,E22,E12=0){
     fixroundingerr(E11*J1^2 + 2*E12*J1*J2 + E22*J2^2)
 }
 errorprop1x3 <- function(J1,J2,J3,E11,E22,E33,E12=0,E13=0,E23=0){
@@ -229,14 +230,14 @@ quotient <- function(X,sX,Y,sY,rXY=NULL,sXY=NULL){
 }
 
 # negative multivariate log likelihood to be fed into R's optim function
-LL.norm <- function(x,covmat){
+LL_norm <- function(x,covmat){
     tryCatch({
         (log(2*pi) + determinant(covmat,logarithmic=TRUE)$modulus
             + stats::mahalanobis(x,center=FALSE,cov=covmat))/2
     },error=function(e) Inf)
 }
 
-set.ellipse.colours <- function(ns=1,levels=NA,col=c('yellow','red'),
+set_ellipse_colours <- function(ns=1,levels=NA,col=c('yellow','red'),
                                 hide=NULL,omit=NULL,omit.col=NA){
     nl <- length(levels)
     if (nl > 1){
@@ -255,6 +256,12 @@ set.ellipse.colours <- function(ns=1,levels=NA,col=c('yellow','red'),
     out[omit] <- omit.col
     out
 }
+# To be removed. Kept for backwards compatibility in provenance 4.2
+set.ellipse.colours <- function(ns=1,levels=NA,col=c('yellow','red'),
+                                hide=NULL,omit=NULL,omit.col=NA){
+    set_ellipse_colours(ns=ns,levels=levels,col=col,
+                        hide=hide,omit=omit,omit.col=omit.col)
+}
 
 levels2colours <- function(levels=c(0,1),col=c('yellow','red')){
     m <- min(levels,na.rm=TRUE)
@@ -371,15 +378,6 @@ clear <- function(x,...,OGLS=FALSE){
     out
 }
 
-geomean <- function(x,...){ UseMethod("geomean",x) }
-geomean.default <- function(x,...){
-    exp(mean(log(x),na.rm=TRUE))
-}
-
-trace <- function(x){
-    sum(diag(x))
-}
-
 logit <- function(x,m=0,M=1,inverse=FALSE){
     out <- x
     if (inverse){
